@@ -2,16 +2,16 @@
 
 
 from .item import Item
-from .mix import ConfigrationMix, DeletionMix
+from .mix import ConfigurationMixIn, DeletionMixIn
 
 
 class Credentials(Item):
 
-    def get(self, name):
+    def get(self, id):
         for item in self.api_json(tree='credentials[id]')['credentials']:
-            if item['id'] == name:
+            if item['id'] == id:
                 return Credential(self.jenkins,
-                                  f'{self.url}credential/{name}/')
+                                  f'{self.url}credential/{id}/')
         return None
 
     def create(self, xml):
@@ -24,5 +24,5 @@ class Credentials(Item):
                              f'{self.url}credential/{item["id"]}/')
 
 
-class Credential(Item, ConfigrationMix, DeletionMix):
+class Credential(Item, ConfigurationMixIn, DeletionMixIn):
     pass
