@@ -1,10 +1,11 @@
 # encoding: utf-8
 
 import json
+import re
 
 from .exceptions import ItemNotFoundError
 from .item import Item
-from .mix import ConfigrationMix, DeletionMix, RunScriptMix
+from .mix import ConfigurationMixIn, DeletionMixIn, RunScriptMixIn
 
 
 class Nodes(Item):
@@ -36,10 +37,7 @@ class Nodes(Item):
     def get(self, name):
         for item in self.api_json(tree='computer[displayName]')['computer']:
             if name == item['displayName']:
-                if name == 'master':
-                    item['url'] = f'{self.url}(master)/'
-                else:
-                    item['url'] = f"{self.url}{item['displayName']}/"
+                item['url'] = f"{self.url}{item['displayName']}/"
                 return self._new_instance_by_item(__name__, item)
         return None
 
@@ -47,19 +45,20 @@ class Nodes(Item):
         tree = 'computer[oneOffExecutors[currentExecutable[url]]]'
         for computer in self.api_json(tree, 2)['computer']:
             for executor in computer.get('oneOffExecutors'):
+                # in case of issue:
+                # https://github.com/joelee2012/api4jenkins/issues/16
+                if not executor['currentExecutable']:
+                    continue
                 yield self._new_instance_by_item('api4jenkins.build',
                                                  executor['currentExecutable'])
 
     def __iter__(self):
         for item in self.api_json(tree='computer[displayName]')['computer']:
-            if item['displayName'] == 'master':
-                item['url'] = f'{self.url}(master)/'
-            else:
-                item['url'] = f"{self.url}{item['displayName']}/"
+            item['url'] = f"{self.url}{item['displayName']}/"
             yield self._new_instance_by_item(__name__, item)
 
 
-class Node(Item, ConfigrationMix, DeletionMix, RunScriptMix):
+class Node(Item, ConfigurationMixIn, DeletionMixIn, RunScriptMixIn):
 
     def enable(self):
         if self.offline:
@@ -79,7 +78,8 @@ class Node(Item, ConfigrationMix, DeletionMix, RunScriptMix):
 
 
 class MasterComputer(Node):
-    pass
+    def __init__(self, jenkins, url):
+        super().__init__(jenkins, re.sub(r'/master/$', '/(master)/', url))
 
 
 class SlaveComputer(Node):
